==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1StatusCauseFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1StatusCauseFluentImpl<A extends V1StatusCauseFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1StatusCauseFluent<A>{

    private String field;
    private String message;
    private String reason;

    public V1StatusCauseFluentImpl(){
    }
    public V1StatusCauseFluentImpl(V1StatusCause instance){
            this.withField(instance.getField());

            this.withMessage(instance.getMessage());

            this.withReason(instance.getReason());

    }

    public String getField(){
            return this.field;
    }

    public A withField(String field){
            this.field=field; return (A) this;
    }

    public Boolean hasField(){
            return this.field != null;
    }

    public String getMessage(){
            return this.message;
    }

    public A withMessage(String message){
            this.message=message; return (A) this;
    }

    public Boolean hasMessage(){
            return this.message != null;
    }

    public String getReason(){
            return this.reason;
    }

    public A withReason(String reason){
            this.reason=reason; return (A) this;
    }

    public Boolean hasReason(){
            return this.reason != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1StatusCauseFluentImpl that = (V1StatusCauseFluentImpl) o;
            if (field != null ? !field.equals(that.field) :that.field != null) return false;
            if (message != null ? !message.equals(that.message) :that.message != null) return false;
            if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1StatusCauseFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1StatusCauseFluentImpl<A extends V1StatusCauseFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1StatusCauseFluent<A>{

    private String field;
    private String message;
    private String reason;

    public V1StatusCauseFluentImpl(){
    }
    public V1StatusCauseFluentImpl(V1StatusCause instance){
            this.withField(instance.getField());

            this.withMessage(instance.getMessage());

            this.withReason(instance.getReason());

    }

    public String getField(){
            return this.field;
    }

    public A withField(String field){
            this.field=field; return (A) this;
    }

    public Boolean hasField(){
            return this.field != null;
    }

    public A withNewField(String arg1){
            return (A)withField(new String(arg1));
    }

    public A withNewField(StringBuilder arg1){
            return (A)withField(new String(arg1));
    }

    public A withNewField(StringBuffer arg1){
            return (A)withField(new String(arg1));
    }

    public String getMessage(){
            return this.message;
    }

    public A withMessage(String message){
            this.message=message; return (A) this;
    }

    public Boolean hasMessage(){
            return this.message != null;
    }

    public A withNewMessage(String arg1){
            return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(StringBuilder arg1){
            return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(StringBuffer arg1){
            return (A)withMessage(new String(arg1));
    }

    public String getReason(){
            return this.reason;
    }

    public A withReason(String reason){
            this.reason=reason; return (A) this;
    }

    public Boolean hasReason(){
            return this.reason != null;
    }

    public A withNewReason(String arg1){
            return (A)withReason(new String(arg1));
    }

    public A withNewReason(StringBuilder arg1){
            return (A)withReason(new String(arg1));
    }

    public A withNewReason(StringBuffer arg1){
            return (A)withReason(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1StatusCauseFluentImpl that = (V1StatusCauseFluentImpl) o;
            if (field != null ? !field.equals(that.field) :that.field != null) return false;
            if (message != null ? !message.equals(that.message) :that.message != null) return false;
            if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
            return true;
    }




}
